#
# spec file for package cscope
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cscope
Version:        15.9
Release:        2.3
Summary:        Interactive Tool for Browsing C Source Code
License:        BSD-3-Clause
Group:          Development/Tools/Navigators
URL:            http://cscope.sourceforge.net/
Source:         http://sourceforge.net/projects/cscope/files/cscope/v%{version}/%{name}-%{version}.tar.gz
Patch1:         cscope-null.patch
Patch2:         cscope-15.7-gcc-warnings.patch
Patch3:         cscope-15.7-vpath.patch
Patch4:         cscope-15.8a-fix-bashisms.patch
Patch5:         cscope-cleanup_on_sigterm.patch
Patch6:         cscope-egrep.out.patch
Patch7:         support-fun-as-params.patch
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig

%description
Cscope is an interactive, screen-oriented tool that allows the user to
browse through C source code files for specified elements of code.

%prep
%setup -q
%patch -P 1 -p1
%patch -P 2
%patch -P 3
%patch -P 4 -p1
%patch -P 5
%patch -P 6 -p1
%patch -P 7 -p1

%build
%configure
%make_build

%install
install -Dpm 0755 src/cscope \
  %{buildroot}%{_bindir}/cscope
install -Dpm 0644 doc/cscope.1 \
  %{buildroot}%{_mandir}/man1/cscope.1
install -Dpm 0755 contrib/xcscope/cscope-indexer \
  %{buildroot}%{_bindir}/cscope-indexer
pushd contrib
%make_install
popd

%files
%license COPYING
%doc TODO ChangeLog AUTHORS README NEWS
%{_bindir}/cscope
%{_bindir}/ocs
%{_bindir}/cscope-indexer
%{_mandir}/man1/cscope.1%{?ext_man}

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Mon Mar 16 2020 Martin Pluskal <mpluskal@suse.com>
- Fix download url
- Clean up spec file with spec-cleaner
* Fri Mar 13 2020 Jiri Slaby <jslaby@suse.com>
- Update to 15.9
  * Fix coverity scan warnings
  * cscope: Add ( and | as metachars in regex search
  * Adding chek on return code of search() in linemode
  * Fix DOS style line endings in one file; enable system C extensions,
  if available
* Thu Mar 23 2017 kstreitova@suse.com
- cleanup with spec-cleaner
- get rid of %%{name} macros in the patch names
* Sat Jan  2 2016 p.drouand@gmail.com
- Update to version 15.8b
  * configure.in: Add check to enable C system extensions (like
    _GNU_SOURCE), if available.
  * contrib/cctree.txt: Format change: file had DOS line endings for
    some reason.
- Adapt cscope-egrep.out.patch to upstream changes
* Thu Apr  2 2015 mpluskal@suse.com
- Use url for source
* Mon Jan  5 2015 jslaby@suse.com
- support-fun-as-params.patch: swallow function as parameters
- remove INSTALL from %%doc, as suggested by the rpm checker
* Thu Nov 20 2014 Led <ledest@gmail.com>
- fix bashisms in osc script
- add patches:
  * cscope-15.8a-fix-bashisms.patch
* Mon Sep  3 2012 sleep_walker@suse.cz
- attempt to fix build for SLE distributions
* Mon Sep  3 2012 sleep_walker@suse.cz
- update to 15.8a
- patches refreshed
- ctrlz patch reached upstream - deleted
* Tue Dec 20 2011 coolo@suse.com
- remove call to suse_update_config (very old work around)
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Wed Jun 22 2011 rcoe@wi.rr.com
- fix carriage return in egrep output
  - added egrep.out patch (bnc#699156)
- fix control-z in interactive curses mode
  - added ctrlz patch (bnc#699317)
* Fri Apr 29 2011 puzel@novell.com
- use spec-cleaner
- package cscope-indexer (bnc#690457)
* Mon May  4 2009 puzel@suse.cz
- updated to 15.7a
  - replace all calls of sprintf by snprintf to avoid
    possible buffer overflows
  remove cscope-15.7-sprintf.patch (obsolete)
* Sat Feb 14 2009 puzel@suse.cz
- update to 15.7
  - bugfix release
  - see /usr/share/doc/packages/cscope/ChangeLog for details
- added flex and bison to BR
- install ocsc helper script to bindir
* Wed Jun 18 2008 anosek@suse.cz
- fixed cscope segfaults when detaching from screen (bnc#398268)
  - applied attached patch (sigwinch-linemode.patch)
* Mon Dec 10 2007 pth@suse.de
- Cleanup on receiving SIGTERM (#339807) and actually include
  the patch.
- Don't remove buildroot in install section
* Fri Mar 30 2007 ro@suse.de
- added ncurses-devel to buildreq
* Fri Nov 10 2006 ro@suse.de
- fix manpage permissions
* Wed Oct 18 2006 anosek@suse.cz
- updated to version 15.6
  * fixed various security issues
- dropped obsolete CVE-2006-4262.patch, tmpfile.patch
* Wed Aug 30 2006 anosek@suse.cz
- fixed previous change
* Tue Aug 29 2006 anosek@suse.de
- fixed multiple buffer overflows [#200534] (CVE-2006-4262.pach)
* Mon May 29 2006 mmarek@suse.cz
- replace sprintf() with snprintf() (patch taken from debian
  package) to avoid buffer overflows such as CVE-2004-2541
  [#177568] (sprintf.patch)
* Mon Feb 27 2006 mmarek@suse.cz
- fix handling of empty VPATH components
  [#152643] (vpath.patch)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Sep 19 2005 mmarek@suse.cz
- fix "control reaches end of non-void function" warning in exec.c
* Sat Jan 29 2005 meissner@suse.de
- use NULL as execlp arglist terminator.
* Mon Nov 29 2004 ltinkl@suse.cz
- fix insecure temp file handling vulnerability (#48541)
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Tue Sep 30 2003 ltinkl@suse.cz
- updated to 15.5
- dropped obsolete patch
* Mon Jan 20 2003 vbobek@suse.cz
- updated to version 15.4 (bugfixes only)
- used $RPM_OPT_FLAGS
* Tue Dec 17 2002 sf@suse.de
- added suse_update_config (bug #22296)
* Thu Nov  7 2002 tcrhak@suse.cz
- fixed egrep.y for bison 1.75:
  use `{ action }' instead of `={ action }'
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Fri Aug 10 2001 pmladek@suse.cz
- updated to version 15.3
- bzipped sources
* Thu Mar 22 2001 pblaha@suse.cz
- add URL
* Fri Dec  1 2000 uzi@suse.com
- Initial package based on version 15.1
